import { ConversionTypeEnum } from './BaseModel.constants';
import { IConversionOption } from './BaseModel.types';
/**
 * A Utility class that has several static methods to assist in development.
 *
 * @author Robert S. (www.codeBelt.com)
 * @static
 */
export declare class Util {
    /**
     * Makes a clone of an object.
     *
     * @param src {Object} The object you to clone.
     * @param renamePropertyName {(keyName: string) => string} Optional function to rename property names
     * @returns {any} Returns a clone object of the one passed in.
     * @example
     *      let cloneOfObject = Util.clone(obj);
     */
    static clone(src: any, renamePropertyName?: (keyName: string) => string): any;
    /**
     * Converts a string or number to a boolean.
     * @example
     *      Util.toBoolean("FALSE");
     *      // false
     *
     *      Util.toBoolean("off");
     *      // false
     *
     *      Util.toBoolean(0);
     *      // false
     *
     *      Util.toBoolean(undefined);
     *      // false
     */
    static toBoolean(value: null | undefined | string | number | boolean): boolean;
    static validConversionOptionNames(data: object, conversionOptions?: IConversionOption): void;
    static convertDataToConversionType(propertyData: null | string | number | boolean, conversionType: ConversionTypeEnum): null | string | number | boolean | object;
    /**
     * Check the data is an object with properties.
     */
    static isObjectWithProperties(data: Record<string, unknown>): boolean;
    /**
     * Check if the data is an object.
     */
    static isObject(data: unknown): boolean;
}
